package App::cpanm::shcompgen;

our $DATE = '2017-08-02'; # DATE
our $VERSION = '0.002'; # VERSION

1;

# ABSTRACT: Install modules from CPAN (and activate shell completion)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::cpanm::shcompgen - Install modules from CPAN (and activate shell completion)

=head1 VERSION

This document describes version 0.002 of App::cpanm::shcompgen (from Perl distribution App-cpanm-shcompgen), released on 2017-08-02.

=head1 DESCRIPTION

See the included L<cpanm-shcompgen> script.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-cpanm-shcompgen>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-cpanm-shcompgen>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-cpanm-shcompgen>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::cpanminus>

L<App::shcompgen>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
